@@ -65,10 +65,6 @@ OC.L10N.register(
     "end" : "fin",
     "Editing reminders of unknown type not supported." : "Nun ta soportáu l'editar recordatorios de triba desconocida",
     "Week {number} of {year}" : "Selmana {number} del {year}",
-    "Successfully imported" : "Importáu ensin fallos",
-    "Partially imported, 1 failure" : "Importáu parcialmente, 1 fallu",
-    "Partially imported, {n} failures" : "Importáu parcialmente, {n} fallos",
-    "Audio alarm" : "Alarma d'audiu",
     "{type} {time} before the event starts" : "{type} {time} enantes que l'enventu entame",
     "{type} {time} before the event ends" : "{type} {time} enantes que l'eventu fine",
     "{type} {time} after the event starts" : "{type} {time} dempués que l'eventu entame",
