@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "konec",
     "Editing reminders of unknown type not supported." : "Úprava upozornění neznámého typu není podporována.",
     "Week {number} of {year}" : "Týden {number} rok {year}",
-    "Successfully imported" : "Úspěšně importován",
-    "Partially imported, 1 failure" : "Částečně importován, 1 chyba",
-    "Partially imported, {n} failures" : "Částečně importován, {n} chyb",
-    "Audio alarm" : "Zvuková upomínka",
     "{type} {time} before the event starts" : "{type} {time} před začátkem události",
     "{type} {time} before the event ends" : "{type} {time} před koncem události",
     "{type} {time} after the event starts" : "{type} {time} po začátku události",
