@@ -74,16 +74,46 @@ OC.L10N.register(
     "end" : "Ende",
     "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
     "Week {number} of {year}" : "Woche {number} aus {year}",
-    "Successfully imported" : "Erfolgreich importiert",
-    "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
-    "Partially imported, {n} failures" : "Teilweise importiert, {n} Fehler",
-    "Audio alarm" : "Akustischer Alarm",
+    "Successfully imported {imported} objects" : "Erfolgreich {imported} Objekte importiert ",
+    "Imported {imported} out of {all}, skipped one duplicate" : "{imported} von {all} importiert, ein Duplikat übersprungen",
+    "Imported {imported} out of {all}, one failure" : "{imported} von {all} importiert, ein Fehler",
+    "Imported {imported} out of {all}, {errors} failures" : "{imported} von {all} importiert, {errors} Fehler",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{imported} von {all} importiert, {duplicates} Duplikate übersprungen",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported} von {all} importiert, {errors} Fehler, {duplicates} Duplikate übersprungen",
+    "Audio alarm {time} before the event starts" : "Audio-Alarm {time} bevor das Ereignis startet",
+    "Pop-up {time} before the event starts" : "Pop-Up-Meldung {time} bevor das Ereignis startet",
+    "Email {time} before the event starts" : "E-Mail {time} bevor das Ereignis startet",
+    "None {time} before the event starts" : "Keine Aktion {time} bevor das Ereignis startet",
     "{type} {time} before the event starts" : "{type} {time} vor Beginn des Ereignisses",
+    "Audio alarm {time} before the event ends" : "Audio-Alarm {time} bevor das Ereignis endet",
+    "Pop-up {time} before the event ends" : "Pop-Up-Meldung {time} bevor das Ereignis endet",
+    "Email {time} before the event ends" : "E-Mail {time} bevor das Ereignis endet",
+    "None {time} before the event ends" : "Keine Aktion {time} bevor das Ereignis endet",
     "{type} {time} before the event ends" : "{type} {time} vor Ende des Ereignisses",
+    "Audio alarm {time} after the event starts" : "Audio-Alarm {time} nachdem das Ereignis startet",
+    "Pop-up {time} after the event starts" : "Pop-Up-Meldung {time} nachdem das Ereignis startet",
+    "Email {time} after the event starts" : "E-Mail {time} nachdem das Ereignis startet",
+    "None {time} after the event starts" : "Keine Aktion {time} nachdem das Ereignis startet",
     "{type} {time} after the event starts" : "{type} {time} nach Beginn des Ereignisses",
+    "Audio alarm {time} after the event ends" : "Audio-Alarm {time} nachdem das Ereignis endete",
+    "Pop-up {time} after the event ends" : "Pop-Up-Meldung {time} nachdem das Ereignis endete",
+    "Email {time} after the event ends" : "E-Mail {time} nachdem das Ereignis endete",
+    "None {time} after the event ends" : "Keine Aktion {time} nachdem das Ereignis endete",
     "{type} {time} after the event ends" : "{type} {time} nach Ende des Ereignisses",
+    "Audio alarm at the event's start" : "Audio-Alarm beim Start des Ereignisses",
+    "Pop-up at the event's start" : "Pop-Up-Meldung beim Start des Ereignisses",
+    "Email at the event's start" : "E-Mail beim Start des Ereignisses",
+    "None at the event's start" : "Keine Aktion beim Start des Ereignisses",
     "{type} at the event's start" : "{type} zu Beginn der Ereignisses",
+    "Audio alarm at the event's end" : "Audio-Alarm beim Ende des Ereignisses",
+    "Pop-up at the event's end" : "Pop-Up-Meldung beim Ende des Ereignisses",
+    "Email at the event's end" : "E-Mail beim Ende des Ereignisses",
+    "None at the event's end" : "Keine Aktion beim Ende des Ereignisses",
     "{type} at the event's end" : "{type} am Ende des Ereignisses",
+    "Audio alarm at {time}" : "Audio-Alarm um {time}",
+    "Pop-up at {time}" : "Pop-Up-Meldung um {time}",
+    "Email at {time}" : "E-Mail um {time}",
+    "None at {time}" : "Keine Aktion um {time}",
     "{type} at {time}" : "{type} um {time}",
     "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
     "Please enter a valid WebCal-URL" : "Bitte eine gültige WebCal-Adresse angeben",
@@ -142,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "Absolut",
     "Repeat" : "Wiederholen",
     "times every" : "mal pro",
+    "Email reminders have not been implemented in the CalDAV server yet, hence no email reminders will be send." : "E-Mail-Erinnerungen wurden bisher noch nicht im CalDAV-Server umgesetzt. Daher werden aktuell keine E-Mail-Erinnerungen gesendet.",
     "Add" : "Hinzufügen",
     "Email address of attendee" : "E-Mail-Adresse des Teilnehmers",
     "Please add your email address in the personal settings in order to add attendees." : "Bitte füge Deine E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
