@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "τέλος",
     "Editing reminders of unknown type not supported." : "Δεν υποστηρίζεται η επεξεργασία υπενθυμίσεων άγνωστου τύπου.",
     "Week {number} of {year}" : "Εβδομάδα {number} του {year}",
-    "Successfully imported" : "Εισήχθη επιτυχώς",
-    "Partially imported, 1 failure" : "Μερική εισαγωγή, 1 αποτυχία",
-    "Partially imported, {n} failures" : "Μερική εισαγωγή, {n} αποτυχίες",
-    "Audio alarm" : "Ηχητκή ειδοποίηση",
     "{type} {time} before the event starts" : "{type} {time} πριν την έναρξη του συμβάντος",
     "{type} {time} before the event ends" : "{type} {time} πριν τη λήξη του συμβάντος",
     "{type} {time} after the event starts" : "{type} {time} μετά την έναρξη του συμβάντος",
