@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "end",
     "Editing reminders of unknown type not supported." : "Editing reminders of unknown type not supported.",
     "Week {number} of {year}" : "Week {number} of {year}",
-    "Successfully imported" : "Successfully imported",
-    "Partially imported, 1 failure" : "Partially imported, 1 failure",
-    "Partially imported, {n} failures" : "Partially imported, {n} failures",
-    "Audio alarm" : "Audio alarm",
     "{type} {time} before the event starts" : "{type} {time} before the event starts",
     "{type} {time} before the event ends" : "{type} {time} before the event ends",
     "{type} {time} after the event starts" : "{type} {time} after the event starts",
