@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "fin",
     "Editing reminders of unknown type not supported." : "La edición de recordatorios de tipo desconocido no tiene respaldo.",
     "Week {number} of {year}" : "Semana {number} de {year}",
-    "Successfully imported" : "Importado exitosamente",
-    "Partially imported, 1 failure" : "Parcialmente importardo, 1 error",
-    "Partially imported, {n} failures" : "Parcialmente importado, {n} errores",
-    "Audio alarm" : "Sonido de alarma",
     "{type} {time} before the event starts" : "{type} {time} antes de que inicie el evento",
     "{type} {time} before the event ends" : "{type} {time} antes de que termine el evento",
     "{type} {time} after the event starts" : "{type} {time} después de que inicie el evento",
