@@ -74,10 +74,12 @@ OC.L10N.register(
     "end" : "lõpp",
     "Editing reminders of unknown type not supported." : "Tundmatud tüüpi meeldetuletuste muutmine pole toetatud.",
     "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
-    "Successfully imported" : "Imporditud",
-    "Partially imported, 1 failure" : "Osaliselt imporditud, 1 ebaõnnestus",
-    "Partially imported, {n} failures" : "Osaliselt imporditud, {n} ebaõnnestus",
-    "Audio alarm" : "Helialarm",
+    "Successfully imported {imported} objects" : "Edukalt imporditud {imported} objektid",
+    "Imported {imported} out of {all}, skipped one duplicate" : "Imporditud {imported}  koguhulgast {all}, välja jäetud üks duplikaat",
+    "Imported {imported} out of {all}, one failure" : "Imporditud {imported}  koguhulgast {all}, üks ebaõnnestus",
+    "Imported {imported} out of {all}, {errors} failures" : "Imporditud {imported}  koguhulgast {all}, ebaõnnestus {errors}",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Imporditud {imported}  koguhulgast {all}, välja jäetud {duplicates} duplikaati",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Imporditud {imported}  koguhulgast {all}, ebaõnnestus {errors}, välja jäetud  {duplicates} duplikaati",
     "{type} at {time}" : "{type} kell {time}",
     "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
     "Please enter a valid WebCal-URL" : "Palun sisesta korrektne WebCal-URL",
@@ -96,6 +98,7 @@ OC.L10N.register(
     "Event status" : "Sündmuse staatus",
     "Visibility when sharing" : "Nähtavus jagamisel",
     "Export" : "Ekspordi",
+    "%s has published the calendar %s" : "%s on avaldanud kalendri %s",
     "Click on the link below to access it" : "Ligipääsuks vajuta allolevale lingile",
     "Day" : "Päev",
     "Week" : "Nädal",
