@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "fin",
     "Editing reminders of unknown type not supported." : "L'édition de rappels de type inconnu n'est pas supportée.",
     "Week {number} of {year}" : "Semaine {number} de {year}",
-    "Successfully imported" : "Importé avec succès",
-    "Partially imported, 1 failure" : "Partiellement importé, 1 échec",
-    "Partially imported, {n} failures" : "Partiellement importé, {n} échecs",
-    "Audio alarm" : "Alerte audio",
     "{type} {time} before the event starts" : "{type} {time} avant l'événement",
     "{type} {time} before the event ends" : "{type} {time} avant la fin de l'événement",
     "{type} {time} after the event starts" : "{type} {time} après le début de l'événement",
