@@ -52,10 +52,6 @@ OC.L10N.register(
     "end" : "סוף",
     "Editing reminders of unknown type not supported." : "עריכת תזכורות מסוגים לא מוכרים אינה נתמכת.",
     "Week {number} of {year}" : "שבוע {number} מ- {year}",
-    "Successfully imported" : "יובא בהצלחה",
-    "Partially imported, 1 failure" : "יובא חלקית, 1 שגיאה",
-    "Partially imported, {n} failures" : "יובא חלקית, {n} שגיאות",
-    "Audio alarm" : "תזכורת קולית",
     "{type} {time} before the event starts" : "{type} {time} לפני תחילת האירוע",
     "{type} {time} before the event ends" : "{type} {time} לפני סיום האירוע",
     "{type} {time} after the event starts" : "{type} {time} אחרי תחילת האירוע",
