@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "vég",
     "Editing reminders of unknown type not supported." : "Ismeretlen típusú emlékeztetős szerkesztése nem támogatott.",
     "Week {number} of {year}" : "{year} év {number}. hete",
-    "Successfully imported" : "Sikeresen importálva!",
-    "Partially imported, 1 failure" : "Részben importálva, 1 hiba",
-    "Partially imported, {n} failures" : "Részben importálva, {n} hiba",
-    "Audio alarm" : "Hangriasztás",
     "{type} {time} before the event starts" : "{type} {time} idő múlva kezdődik az esemény",
     "{type} {time} before the event ends" : "{type} {time} idő múlva végződik az esemény",
     "{type} {time} after the event starts" : "{type} {time} esemény kezdete után",
