@@ -64,10 +64,6 @@ OC.L10N.register(
     "end" : "fin",
     "Editing reminders of unknown type not supported." : "Modificar mementos de typos incognite non es supportate.",
     "Week {number} of {year}" : "Septimana {number} de {year}",
-    "Successfully imported" : "Importate con successo",
-    "Partially imported, 1 failure" : "Partialmente importate, 1 fallimento",
-    "Partially imported, {n} failures" : "Partialmente importate, {n} fallimentos",
-    "Audio alarm" : "Alarma in audio",
     "{type} {time} before the event starts" : "{type} {time} ante que le evento initia",
     "{type} {time} before the event ends" : "{type} {time} ante que le evento fini",
     "{type} {time} after the event starts" : "{type} {time} post que le evento initia",
