@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "endir",
     "Editing reminders of unknown type not supported." : "Breytingar á áminningum með óþekktu sniði er ekki stutt.",
     "Week {number} of {year}" : "Vika {number},{year}",
-    "Successfully imported" : "Innflutningur tókst",
-    "Partially imported, 1 failure" : "Flutt inn að hluta, 1 villa",
-    "Partially imported, {n} failures" : "Flutt inn að hluta, {n} villur",
-    "Audio alarm" : "Hljóðáminning",
     "{type} {time} before the event starts" : "{type} {time} áður en atburður hefst",
     "{type} {time} before the event ends" : "{type} {time} áður en atburður endar",
     "{type} {time} after the event starts" : "{type} {time} eftir að atburður hefst",
