@@ -74,16 +74,30 @@ OC.L10N.register(
     "end" : "finisce",
     "Editing reminders of unknown type not supported." : "La modifica di promemoria di tipo sconosciuto non è supportata.",
     "Week {number} of {year}" : "Settimana {number} del {year}",
-    "Successfully imported" : "Importato correttamente",
-    "Partially imported, 1 failure" : "Importato parzialmente, 1 problema",
-    "Partially imported, {n} failures" : "Importato parzialmente, {n} problemi",
-    "Audio alarm" : "Avviso sonoro",
+    "Successfully imported {imported} objects" : "{imported} oggetti importati correttamente",
+    "Imported {imported} out of {all}, skipped one duplicate" : "{imported} importati di {all}, saltato un duplicato",
+    "Imported {imported} out of {all}, one failure" : "{imported} importati di {all}, uno non riuscito",
+    "Imported {imported} out of {all}, {errors} failures" : "{imported} importati di {all}, {errors} non riusciti",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{imported} importati di {all}, saltati {duplicates} duplicati",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported} importati di {all}, {errors} non riusciti, saltati {duplicates} duplicati",
     "{type} {time} before the event starts" : "{type} {time} prima dell'inizio dell'evento",
     "{type} {time} before the event ends" : "{type} {time} prima della fine dell'evento",
     "{type} {time} after the event starts" : "{type} {time} dopo l'inizio dell'evento",
     "{type} {time} after the event ends" : "{type} {time} dopo la fine dell'evento",
+    "Audio alarm at the event's start" : "Avviso sonoro quando inizia l'evento",
+    "Pop-up at the event's start" : "Finestra a comparsa quando inizia l'evento",
+    "Email at the event's start" : "Email quando inizia l'evento",
+    "None at the event's start" : "Niente quando inizia l'evento",
     "{type} at the event's start" : "{type} all'inizio dell'evento",
+    "Audio alarm at the event's end" : "Avviso sonoro quando finisce l'evento",
+    "Pop-up at the event's end" : "Finestra a comparsa quando finisce l'evento",
+    "Email at the event's end" : "Email quando finisce l'evento",
+    "None at the event's end" : "Niente quando finisce l'evento",
     "{type} at the event's end" : "{type} alla fine dell'evento",
+    "Audio alarm at {time}" : "Avviso sonoro alle {time} ",
+    "Pop-up at {time}" : "Finestra a comparsa alle {time} ",
+    "Email at {time}" : "Email alle {time}",
+    "None at {time}" : "Niente alle {time}",
     "{type} at {time}" : "{type} il {time}",
     "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
     "Please enter a valid WebCal-URL" : "Digita un URL WebCal valido",
@@ -142,6 +156,7 @@ OC.L10N.register(
     "Absolute" : "Assoluto",
     "Repeat" : "Ripeti",
     "times every" : "volte ogni",
+    "Email reminders have not been implemented in the CalDAV server yet, hence no email reminders will be send." : "I promemoria via email non sono ancora stati implementati nel server CalDAV, per cui non sarà inviato alcuna promemoria tramite posta.",
     "Add" : "Aggiungi",
     "Email address of attendee" : "Indirizzo email del partecipante",
     "Please add your email address in the personal settings in order to add attendees." : "Aggiungi il tuo indirizzo email nelle impostazioni personali per aggiungere i partecipanti.",
