@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "終了",
     "Editing reminders of unknown type not supported." : "未知のタイプのリマインダの編集はサポートされていません。",
     "Week {number} of {year}" : "{year}の{number} 週",
-    "Successfully imported" : "インポートに成功しました",
-    "Partially imported, 1 failure" : "不完全なインポート，失敗1",
-    "Partially imported, {n} failures" : "不完全なインポート，失敗{n}",
-    "Audio alarm" : "オーディオアラーム",
     "{type} {time} before the event starts" : "イベント開始の{type} {time} 前",
     "{type} {time} before the event ends" : "イベント終了の{type} {time} 前",
     "{type} {time} after the event starts" : "イベント開始の{type} {time} 後",
