@@ -64,10 +64,6 @@ OC.L10N.register(
     "end" : "끝",
     "Editing reminders of unknown type not supported." : "알 수 없는 형식의 미리 알림을 편집할 수 없습니다.",
     "Week {number} of {year}" : "{year}년 제 {number}주",
-    "Successfully imported" : "성공적으로 가져옴",
-    "Partially imported, 1 failure" : "일부만 가져옴, 1개 항목 실패",
-    "Partially imported, {n} failures" : "일부만 가져옴, {n}개 항목 실패",
-    "Audio alarm" : "오디오 알람",
     "{type} {time} before the event starts" : "일정 시작 {time} 전 {type}",
     "{type} {time} before the event ends" : "일정 종료 {time} 전 {type}",
     "{type} {time} after the event starts" : "일정 시작 {time} 후 {type}",
