@@ -49,10 +49,6 @@ OC.L10N.register(
     "end" : "Ophalen",
     "Editing reminders of unknown type not supported." : "D'ännere vun onbekannten Typpen vun Erënnerungen gëtt net ënnerstëtzt.",
     "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
-    "Successfully imported" : "Erfollegräich erageholl",
-    "Partially imported, 1 failure" : "Deelweis erageholl, 1 Fehler",
-    "Partially imported, {n} failures" : "Deelweis erageholl, {n} Fehler",
-    "Audio alarm" : "Toun Alarm",
     "{type} {time} before the event starts" : "{tipp} {Zäit} éier d'Evenement ufänkt",
     "{type} {time} before the event ends" : "{tipp} {Zäit} éier d'Evenement ophält",
     "{type} {time} after the event starts" : "{tipp} {Zäit} nodeems en Evenement ufänkt ",
