@@ -67,10 +67,6 @@ OC.L10N.register(
     "end" : "beigas",
     "Editing reminders of unknown type not supported." : "Nezināma tipa atgādinājumu rediģēšana netiek atbalstīta",
     "Week {number} of {year}" : "{number} nedēļa no {year}",
-    "Successfully imported" : "Veiksmīgi importēts",
-    "Partially imported, 1 failure" : "Daļēji importēts, 1 kļūda",
-    "Partially imported, {n} failures" : "Daļēji importēts, {n} kļūdas",
-    "Audio alarm" : "Audio signāls",
     "{type} {time} before the event starts" : "{type} {time} pirms notikuma sākuma",
     "{type} {time} before the event ends" : "{type} {time} pirms notikuma beigām",
     "{type} {time} after the event starts" : "{type} {time} pēc notikuma sākuma",
