@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "slutt",
     "Editing reminders of unknown type not supported." : "Redigering av varsler av ukjent type støttes ikke.",
     "Week {number} of {year}" : "Uke {number} {year}",
-    "Successfully imported" : "Importert",
-    "Partially imported, 1 failure" : "Delvis importert, 1 feil",
-    "Partially imported, {n} failures" : "Delvis importert, {n} feil",
-    "Audio alarm" : "Lydsignal",
     "{type} {time} before the event starts" : "{type} {time} før hendelsen starter",
     "{type} {time} before the event ends" : "{type} {time} før hendelsen slutter",
     "{type} {time} after the event starts" : "{type} {time} etter hendelsen starter",
