@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "einde",
     "Editing reminders of unknown type not supported." : "Bewerken van herinneringen van onbekende types wordt niet ondersteund.",
     "Week {number} of {year}" : "Week {number} van {year}",
-    "Successfully imported" : "Succesvol geïmporteerd",
-    "Partially imported, 1 failure" : "Gedeeltelijk geïmporteerd, 1 fout",
-    "Partially imported, {n} failures" : "Gedeeltelijk geïmporteerd, {n} fouten",
-    "Audio alarm" : "Audio alarm",
     "{type} {time} before the event starts" : "{type} {time} voor het begin van de afspraak",
     "{type} {time} before the event ends" : "{type} {time} voor het eind van de afspraak",
     "{type} {time} after the event starts" : "{type} {time} na het begin van de afspraak",
