@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "zakończ",
     "Editing reminders of unknown type not supported." : "Edycja przypomnień nieznanego typu nie jest wspierana.",
     "Week {number} of {year}" : "{number}. tydzień {year}",
-    "Successfully imported" : "Import zakończył się pomyślnie",
-    "Partially imported, 1 failure" : "Import wykonany częściowo, 1 błąd",
-    "Partially imported, {n} failures" : "Import wykonany częściowo, {n} błędy/błędów",
-    "Audio alarm" : "Alarm dźwiękowy",
     "{type} {time} before the event starts" : "{type} {time} przed rozpoczęciem wydarzenia",
     "{type} {time} before the event ends" : "{type} {time} przed zakończeniem wydarzenia",
     "{type} {time} after the event starts" : "{type} {time} po rozpoczęciu wydarzenia",
