@@ -74,16 +74,46 @@ OC.L10N.register(
     "end" : "fim",
     "Editing reminders of unknown type not supported." : "Edição de lembretes de tipos desconhecidos não são suportados.",
     "Week {number} of {year}" : "Semana {number} de {year}",
-    "Successfully imported" : "Importada",
-    "Partially imported, 1 failure" : "Parcialmente importada, 1 falha",
-    "Partially imported, {n} failures" : "Parcialmente importada, {n} falha",
-    "Audio alarm" : "Alarme sonoro",
+    "Successfully imported {imported} objects" : "Objetos importados {imported} com sucesso",
+    "Imported {imported} out of {all}, skipped one duplicate" : "Importados {imported} de {all}, uma duplicata ignorada",
+    "Imported {imported} out of {all}, one failure" : "Importados {imported} de {all}, uma falha",
+    "Imported {imported} out of {all}, {errors} failures" : "Importados {imported} de {all}, {errors} falhas",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Importados {imported} de {all}, {duplicates} duplicatas ignoradas",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Importados {imported} de {all}, {errors} falhas, {duplicates} duplicatas ignoradas",
+    "Audio alarm {time} before the event starts" : "Alarme de áudio {time} antes do evento começar",
+    "Pop-up {time} before the event starts" : "Janela popup {time} antes do evento começar",
+    "Email {time} before the event starts" : "Email {time} antes do evento começar",
+    "None {time} before the event starts" : "Nada {time} antes do evento começar",
     "{type} {time} before the event starts" : "{type} {time} antes do evento iniciar",
+    "Audio alarm {time} before the event ends" : "Alarme de áudio {time} antes do evento terminar",
+    "Pop-up {time} before the event ends" : "Janela popup {time} antes do evento terminar",
+    "Email {time} before the event ends" : "Email  {time} antes do evento terminar",
+    "None {time} before the event ends" : "Nada {time} antes do evento terminar",
     "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
+    "Audio alarm {time} after the event starts" : "Alarme de áudio {time} após o evento começar",
+    "Pop-up {time} after the event starts" : "Janela popup {time} após o evento começar",
+    "Email {time} after the event starts" : "Email {time} após o evento começar",
+    "None {time} after the event starts" : "Nada {time} após o evento começar",
     "{type} {time} after the event starts" : "{type} {time} após o evento iniciar",
+    "Audio alarm {time} after the event ends" : "Alarme de áudio {time} após o evento terminar",
+    "Pop-up {time} after the event ends" : "Janela popup {time} após o evento terminar",
+    "Email {time} after the event ends" : "Email {time} após o evento terminar",
+    "None {time} after the event ends" : "Nada {time} após o evento terminar",
     "{type} {time} after the event ends" : "{type} {time} após o evento terminar",
+    "Audio alarm at the event's start" : "Alarme de áudio no início do evento",
+    "Pop-up at the event's start" : "Janela popup no início do evento",
+    "Email at the event's start" : "Email no início do evento",
+    "None at the event's start" : "Nada no início do evento",
     "{type} at the event's start" : "{type} no início do evento",
+    "Audio alarm at the event's end" : "Alarme de áudio no fim do evento",
+    "Pop-up at the event's end" : "Janela popup no fim do evento",
+    "Email at the event's end" : "Email no fim do evento",
+    "None at the event's end" : "Nada no fim do evento",
     "{type} at the event's end" : "{type} no final do evento",
+    "Audio alarm at {time}" : "Alarme de áudio em {time}",
+    "Pop-up at {time}" : "Janela popup em {time}",
+    "Email at {time}" : "Email em {time}",
+    "None at {time}" : "Nada em {time}",
     "{type} at {time}" : "{type} em {time}",
     "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
     "Please enter a valid WebCal-URL" : "Por favor entre uma URL válida para WEbCal",
@@ -142,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "Absoluto",
     "Repeat" : "Repetir",
     "times every" : "vezes a cada",
+    "Email reminders have not been implemented in the CalDAV server yet, hence no email reminders will be send." : "Lembretes via email ainda não foram implementados no servidor CalDAV então nenhum destes lembretes será enviado.",
     "Add" : "Adicionar",
     "Email address of attendee" : "Endereço de e-mail do atendente",
     "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de e-mail nas configurações pessoais, a fim de adicionar participantes.",
