@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "sfârșit",
     "Editing reminders of unknown type not supported." : "Editarea memento-urilor de tip necunoscut nu sunt suportate.",
     "Week {number} of {year}" : "Săptămâna {number} din {year}",
-    "Successfully imported" : "Importat cu succes",
-    "Partially imported, 1 failure" : "Importat parțial, o eroare",
-    "Partially imported, {n} failures" : "Importat parțial, {n} erori",
-    "Audio alarm" : "Alarmă audio",
     "{type} {time} before the event starts" : "{type} {time} înainte de începerea evenimentului",
     "{type} {time} before the event ends" : "{type} {time} înainte de sfârșitul evenimentului",
     "{type} {time} after the event starts" : "{type} {time} după începerea evenimentului",
