@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "окончания",
     "Editing reminders of unknown type not supported." : "Редактирование напоминаний неизвестного типа не поддерживается.",
     "Week {number} of {year}" : "{number} неделя {year} года",
-    "Successfully imported" : "Успешно импортировано",
-    "Partially imported, 1 failure" : "Частично импортировано, 1 ошибка",
-    "Partially imported, {n} failures" : "Частично импортировано, {n} ошибок",
-    "Audio alarm" : "Звуковой сигнал",
     "{type} {time} before the event starts" : "{type} {time} до начала события",
     "{type} {time} before the event ends" : "{type} {time} до окончания события",
     "{type} {time} after the event starts" : "{type} {time} после начала события",
