@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "konec",
     "Editing reminders of unknown type not supported." : "Urejanje opomnikov neznane vrste ni podprto.",
     "Week {number} of {year}" : "{number}. teden leta {year}",
-    "Successfully imported" : "Uvoz uspešno končan",
-    "Partially imported, 1 failure" : "Delno uvoženo, zaznana je 1 napaka",
-    "Partially imported, {n} failures" : "Delno uvoženo, zaznanih je {n} napak",
-    "Audio alarm" : "Zvočni alarm",
     "{type} {time} before the event starts" : "{type} {time} preden se dogodek začne",
     "{type} {time} before the event ends" : "{type} {time} preden se dogodek konča",
     "{type} {time} after the event starts" : "{type} {time} po začetku dogodka",
