@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "mbarim",
     "Editing reminders of unknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
     "Week {number} of {year}" : "Java e {number} e {year}",
-    "Successfully imported" : "U importua me sukses",
-    "Partially imported, 1 failure" : "Importuar pjesërisht, 1 dështim",
-    "Partially imported, {n} failures" : "Importuar pjesërisht, {n} dështime",
-    "Audio alarm" : "Alarm audio",
     "{type} {time} before the event starts" : "{type} {time} para se veprimtaria të fillojë",
     "{type} {time} before the event ends" : "{type} {time} para se veprimtaria të përfundojë",
     "{type} {time} after the event starts" : "{type} {time} pas fillimit të veprimtarisë",
