@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "завршетак",
     "Editing reminders of unknown type not supported." : "Измена подсетника непознатог типа није подржана.",
     "Week {number} of {year}" : "Недеља {number} у {year}",
-    "Successfully imported" : "Успешно увезено",
-    "Partially imported, 1 failure" : "Делимично увезено, 1 неуспео",
-    "Partially imported, {n} failures" : "Делимично увезено, {n} неуспелих",
-    "Audio alarm" : "Звучни аларм",
     "{type} {time} before the event starts" : "{type} {time} пре него догађај почне",
     "{type} {time} before the event ends" : "{type} {time} пре него се догађај заврши",
     "{type} {time} after the event starts" : "{type} {time} пошто догађај почне",
