@@ -74,16 +74,46 @@ OC.L10N.register(
     "end" : "bitiş",
     "Editing reminders of unknown type not supported." : "Bilinmeyen türdeki anımsatıcıların düzenlenmesi desteklenmiyor.",
     "Week {number} of {year}" : "{year} yılının {number}. haftası",
-    "Successfully imported" : "İçe aktarıldı",
-    "Partially imported, 1 failure" : "Kısmen içe aktarıldı, 1 öge aktarılamadı",
-    "Partially imported, {n} failures" : "Kısmen içe aktarıldı, {n} öge aktarılamadı",
-    "Audio alarm" : "Sesli uyarı",
+    "Successfully imported {imported} objects" : "{imported} nesne içe aktarıldı",
+    "Imported {imported} out of {all}, skipped one duplicate" : "{imported} / {all} içe aktarıldı, bir çift kayıt atlandı",
+    "Imported {imported} out of {all}, one failure" : "{imported} / {all} içe aktarıldı, bir kayıt içe aktarılamadı",
+    "Imported {imported} out of {all}, {errors} failures" : "{imported} / {all} içe aktarıldı, {errors} kayıt içe aktarılamadı",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "{imported} / {all} içe aktarıldı, {duplicates} çift kayıt atlandı",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "{imported} / {all} içe aktarıldı, {errors} kayıt içe aktarılamadı {duplicates} çift kayıt atlandı",
+    "Audio alarm {time} before the event starts" : "Etkinlik başlamadan {time} süre önce sesli uyarı",
+    "Pop-up {time} before the event starts" : "Etkinlik başlamadan {time} süre önce açılan pencere ile uyarı",
+    "Email {time} before the event starts" : "Etkinlik başlamadan {time} süre önce e-posta ile uyarı",
+    "None {time} before the event starts" : "Etkinlik başlamadan {time} süre önce uyarı yok",
     "{type} {time} before the event starts" : "Etkinlik başlamadan {time} önce {type}",
+    "Audio alarm {time} before the event ends" : "Etkinlik bitmeden {time} süre önce sesli uyarı",
+    "Pop-up {time} before the event ends" : "Etkinlik bitmeden {time} süre önce açılan pencere ile uyarı",
+    "Email {time} before the event ends" : "Etkinlik bitmeden {time} süre önce e-posta ile uyarı",
+    "None {time} before the event ends" : "Etkinlik bitmeden {time} süre önce uyarı yok",
     "{type} {time} before the event ends" : "Etkinlik bitmeden {time} önce {type}",
+    "Audio alarm {time} after the event starts" : "Etkinlik başladıktan {time} süre sonra sesli uyarı",
+    "Pop-up {time} after the event starts" : "Etkinlik başladıktan {time} süre sonra açılan pencere ile uyarı",
+    "Email {time} after the event starts" : "Etkinlik başladıktan {time} süre sonra e-posta ile uyarı",
+    "None {time} after the event starts" : "Etkinlik başladıktan {time} süre sonra uyarı yok",
     "{type} {time} after the event starts" : "Etkinlik başladıktan {time} sonra {type}",
+    "Audio alarm {time} after the event ends" : "Etkinlik bittikten {time} süre sonra sesli uyarı",
+    "Pop-up {time} after the event ends" : "Etkinlik bittikten {time} süre sonra açılan pencere ile uyarı",
+    "Email {time} after the event ends" : "Etkinlik bittikten {time} süre sonra e-posta ile uyarı",
+    "None {time} after the event ends" : "Etkinlik bittikten {time} süre sonra uyarı yok",
     "{type} {time} after the event ends" : "Etkinlik bittikten {time} sonra {type}",
+    "Audio alarm at the event's start" : "Etkinlik başlangıcında sesli uyarı",
+    "Pop-up at the event's start" : "Etkinlik başlangıcında açılan pencere ile uyarı",
+    "Email at the event's start" : "Etkinlik başlangıcında e-posta ile uyarı",
+    "None at the event's start" : "Etkinlik başlangıcında uyarı yok",
     "{type} at the event's start" : "Etkinlik başlangıcında {type}",
+    "Audio alarm at the event's end" : "Etkinlik bitişinde sesli uyarı",
+    "Pop-up at the event's end" : "Etkinlik bitişinde açılan pencere ile uyarı",
+    "Email at the event's end" : "Etkinlik bitişinde e-posta ile uyarı",
+    "None at the event's end" : "Etkinlik bitişinde uyarı yok",
     "{type} at the event's end" : "Etkinlik bitiminde {type}",
+    "Audio alarm at {time}" : "{time} zamanında sesli uyarı",
+    "Pop-up at {time}" : "{time} zamanında açılan pencere ile uyarı",
+    "Email at {time}" : "{time} zamanında e-posta ile uyarı",
+    "None at {time}" : "{time} zamanında uyarı yok",
     "{type} at {time}" : "{time} zamanında {type}",
     "{calendar} shared by {owner}" : "{owner} tarafından paylaşılmış {calendar}",
     "Please enter a valid WebCal-URL" : "Lütfen geçerli bir WebCal adresi yazın",
