@@ -57,10 +57,6 @@ OC.L10N.register(
     "end" : "кінець",
     "Editing reminders of unknown type not supported." : "Редагування нагадування невідомого типу не підтримується.",
     "Week {number} of {year}" : "Тиждень {number} з {year}",
-    "Successfully imported" : "Імпорт завершено успішно",
-    "Partially imported, 1 failure" : "Частково імпортовано, 1 збій",
-    "Partially imported, {n} failures" : "Частково імпортовано, {n} збоїв",
-    "Audio alarm" : "Звукове попередження",
     "Title of the Event" : "Назва події",
     "Delete" : "Видалити",
     "Cancel" : "Скасувати",
