@@ -74,10 +74,6 @@ OC.L10N.register(
     "end" : "结束",
     "Editing reminders of unknown type not supported." : "不支持未知类型的编辑提醒",
     "Week {number} of {year}" : "{year}年的第{number}周",
-    "Successfully imported" : "导入成功",
-    "Partially imported, 1 failure" : "部分导入成功，1个失败",
-    "Partially imported, {n} failures" : "部分导入成功，{n} 个失败",
-    "Audio alarm" : "声音提醒",
     "{type} {time} before the event starts" : "事件开始前 {type} {time} ",
     "{type} {time} before the event ends" : "事件结束前 {type} {time} ",
     "{type} {time} after the event starts" : "事件开始后 {type} {time} ",
